@@ -1,9 +1,9 @@
 package Net::DNS::RR;
 
 #
-# $Id: RR.pm 1606 2017-11-30 10:13:43Z willem $
+# $Id: RR.pm 1714 2018-09-21 14:14:55Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1606 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1714 $)[1];
 
 
 =head1 NAME
@@ -135,7 +135,7 @@ sub _new_string {
 		my $rdlen = shift(@token) || 0;
 		my $rdata = pack 'H*', join( '', @token );
 		croak 'length and hexadecimal data inconsistent' unless $rdlen == length $rdata;
-		$self->rdata($rdata) if $rdlen;			# unpack RDATA
+		$self->rdata($rdata);				# unpack RDATA
 		return $self;
 	}
 
@@ -182,13 +182,12 @@ sub _new_hash {
 		$attribute{lc $key} = shift;
 	}
 
-	my ( $owner, $name, $type, $class, $ttl ) = @attribute{@core};
-	delete @attribute{@core};				# leaving RDATA only
+	my ( $owner, $name, $type, $class, $ttl ) = delete @attribute{@core};
 
-	my $self = $base->_subclass( $type, scalar %attribute );
+	my $self = $base->_subclass( $type, scalar(%attribute) );
 	$self->owner( $name ? $name : $owner );
-	$self->class($class) if defined $class;			# specify CLASS
-	$self->ttl($ttl)     if defined $ttl;			# specify TTL
+	$self->class($class) if defined $class;			# optional CLASS
+	$self->ttl($ttl)     if defined $ttl;			# optional TTL
 
 	eval {
 		while ( my ( $attribute, $value ) = each %attribute ) {
@@ -269,11 +268,9 @@ sub encode {
 	my ( $offset, @opaque ) = scalar(@_) ? @_ : ( 0x4000, {} );
 
 	my $owner = $self->{owner}->encode( $offset, @opaque );
-	my $type  = $self->{type};
-	my $class = $self->{class} || 1;
-	my $index = $offset + length($owner) + RRFIXEDSZ;
-	my $rdata = eval { $self->_empty ? '' : $self->_encode_rdata( $index, @opaque ); } || '';
-	return pack 'a* n2 N n a*', $owner, $type, $class, $self->ttl, length $rdata, $rdata;
+	my ( $type, $class, $ttl ) = @{$self}{qw(type class ttl)};
+	my $rdata = $self->_empty ? '' : $self->_encode_rdata( $offset + length($owner) + RRFIXEDSZ, @opaque );
+	pack 'a* n2 N n a*', $owner, $type, $class || 1, $ttl || 0, length $rdata, $rdata;
 }
 
 
@@ -294,11 +291,9 @@ sub canonical {
 	my $self = shift;
 
 	my $owner = $self->{owner}->canonical;
-	my $type  = $self->{type};
-	my $class = $self->{class} || 1;
-	my $index = RRFIXEDSZ + length $owner;
-	my $rdata = eval { $self->_empty ? '' : $self->_encode_rdata($index); } || '';
-	pack 'a* n2 N n a*', $owner, $type, $class, $self->ttl, length $rdata, $rdata;
+	my ( $type, $class, $ttl ) = @{$self}{qw(type class ttl)};
+	my $rdata = $self->_empty ? '' : $self->_encode_rdata( length($owner) + RRFIXEDSZ );
+	pack 'a* n2 N n a*', $owner, $type, $class || 1, $ttl || 0, length $rdata, $rdata;
 }
 
 
@@ -306,8 +301,8 @@ sub canonical {
 
     $rr->print;
 
-Prints the record to the standard output.  Calls the string method
-to get the formatted RR representation.
+Prints the resource record to the currently selected output filehandle.
+Calls the string method to get the formatted RR representation.
 
 =cut
 
@@ -320,10 +315,10 @@ sub print {
 
     print $rr->string, "\n";
 
-Returns a string representation of the RR using the zone file format
-described in RFC1035.  All domain names are fully qualified with
-trailing dot.  This differs from RR attribute methods, which omit
-the trailing dot.
+Returns a string representation of the RR using the master file format
+mandated by RFC1035.
+All domain names are fully qualified with trailing dot.
+This differs from RR attribute methods, which omit the trailing dot.
 
 =cut
 
@@ -335,7 +330,7 @@ sub string {
 	my @core = ( $name, @ttl, $self->class, $self->type );
 
 	my $empty = $self->_empty;
-	my @rdata = eval { $empty ? () : $self->_format_rdata; };
+	my @rdata = $empty ? () : eval { $self->_format_rdata };
 	carp $@ if $@;
 
 	my $tab = length($name) < 72 ? "\t" : ' ';
@@ -354,9 +349,9 @@ sub string {
 
     $plain = $rr->plain;
 
-Returns a simplified single line representation of the RR using the
-zone file format defined in RFC1035.  This facilitates interaction
-with programs like nsupdate which have rudimentary RR parsers.
+Returns a simplified single-line representation of the RR.
+This facilitates interaction with programs like nsupdate
+which have rudimentary parsers.
 
 =cut
 
@@ -379,7 +374,7 @@ sub token {
 	my @ttl = grep defined, $self->{ttl};
 	my @core = ( $self->{owner}->string, @ttl, $self->class, $self->type );
 
-	my @rdata = eval { $self->_empty ? () : $self->_format_rdata; };
+	my @rdata = $self->_empty ? () : eval { $self->_format_rdata };
 
 	# parse into quoted strings, contiguous non-whitespace and (discarded) comments
 	my @parse = map { s/\\\\/\\092/g; s/\\"/\\034/g; split /$PARSE_REGEX/o; } @rdata;
@@ -544,7 +539,7 @@ Resource record data section when viewed as opaque octets.
 sub rdata {
 	my $self = shift;
 
-	return eval { $self->_empty ? '' : $self->_encode_rdata( 0x4000, {} ); } || '' unless @_;
+	return $self->_empty ? '' : eval { $self->_encode_rdata( 0x4000, {} ) } unless @_;
 
 	my $data = shift || '';
 	my $hash = {};
@@ -564,7 +559,7 @@ Returns a string representation of the RR-specific data.
 sub rdstring {
 	my $self = shift;
 
-	my @rdata = eval { $self->_empty ? () : $self->_format_rdata; };
+	my @rdata = $self->_empty ? () : eval { $self->_format_rdata };
 	carp $@ if $@;
 
 	join "\n\t", _wrap(@rdata);
@@ -664,7 +659,7 @@ sub get_rrsort_func {
 # The optional second argument indicates that default values are
 # to be copied into the newly created object.
 
-our %_MINIMAL = ( 'ANY' => bless ['type' => 255], __PACKAGE__ );
+our %_MINIMAL = ( 255 => bless ['type' => 255], __PACKAGE__ );
 our %_LOADED = %_MINIMAL;
 
 sub _subclass {
@@ -720,7 +715,7 @@ sub _annotation {
 my %ignore = map( ( $_ => 1 ), @core, 'annotation', '#' );
 
 sub _empty {
-	( $_[0]->{'#'} ||= scalar grep !$ignore{$_}, keys %{$_[0]} ) == 0;
+	not( $_[0]->{'#'} ||= scalar grep !$ignore{$_}, keys %{$_[0]} );
 }
 
 
